@@ -22,11 +22,11 @@ TAP::Harness - Run test scripts with statistics
 
 =head1 VERSION
 
-Version 2.99_07
+Version 2.99_08
 
 =cut
 
-$VERSION = '2.99_07';
+$VERSION = '2.99_08';
 
 $ENV{HARNESS_ACTIVE}  = 1;
 $ENV{HARNESS_VERSION} = $VERSION;
@@ -125,77 +125,6 @@ BEGIN {
 
 =head2 Class Methods
 
-=head3 C<auto_inherit>
-
-Defaults to false.  Set this class constant to true in your harness
-subclass to engage in "chained cooperative inheritance."  If your
-subclass declares this, it is a promis to not get in the way of other
-subclasses -- e.g. it should do things such call SUPER::method() from
-any overridden methods.
-
-  use base 'TAP::Harness';
-  use constant auto_inherit => 1;
-
-=cut
-
-use constant auto_inherit => 0;
-
-=head3 C<inherit>
-
-When `prove` needs to utilize multiple harness subclasses, they are
-built into a chain of "cooperative inheritance" (provided that their
-C<auto_inherit()> method is true.)
-
-  $class->inherit($base_class);
-
-This allows multiple classes, all of which inherit directly from
-C<TAP::Harness>, to be stacked:
-
-    package Foo;
-    our @ISA = qw( TAP::Harness );
-    use constant auto_inherit => 1;
-
-    package Bar;
-    our @ISA = qw( TAP::Harness );
-    use constant auto_inherit => 1;
-
-    Bar->inherit('Foo');
-
-Would create an inheritance chain like this:
-
-    Bar ISA Foo ISA TAP::Harness
-
-This feature is only a temporary measure to allow experimentation with
-customizations.  The programmer is advised to be aware of which other
-subclasses are involved and what they do.
-
-=cut
-
-sub inherit {
-    my ( $class, $base_class ) = @_;
-
-    croak("missing required '\$base_class' argument")
-      unless ( defined($base_class) );
-
-    my $your_isa = do { no strict 'refs'; \@{"${class}::ISA"}; };
-
-    my ( $i, @and )
-      = grep { $your_isa->[$_] eq __PACKAGE__ } 0 .. $#$your_isa;
-    if ( defined($i) ) {
-        splice( @$your_isa, $_, 1 ) for (@and);    # cleanup (should we?)
-        splice( @$your_isa, $i, 1, $base_class );
-    }
-    else {
-
-        # TODO we really shouldn't get here, but the grep should do
-        # something more interesting -- e.g. with isa()
-        croak('cannot inherit() without isa TAP::Harness');
-
-        # if we weren't there already, be nice like 'use base'
-        push( @$your_isa, $base_class );
-    }
-}
-
 =head3 C<new>
 
  my %args = (
