@@ -19,11 +19,11 @@ TAP::Parser - Parse L<TAP|Test::Harness::TAP> output
 
 =head1 VERSION
 
-Version 2.99_07
+Version 2.99_08
 
 =cut
 
-$VERSION = '2.99_07';
+$VERSION = '2.99_08';
 
 my $DEFAULT_TAP_VERSION = 12;
 my $MAX_TAP_VERSION     = 13;
@@ -1195,9 +1195,7 @@ sub _iter {
                 $self->wait( $stream->wait );
                 $self->_finish;
 
-                if ( my $code = $self->_callback_for('EOF') ) {
-                    $_->($self) for @$code;
-                }
+                $self->_make_callback( 'EOF', $result );
             }
 
             return $result;
