@@ -38,11 +38,11 @@ Test::Harness - Run Perl standard test scripts with statistics
 
 =head1 VERSION
 
-Version 2.99_07
+Version 2.99_08
 
 =cut
 
-$VERSION = '2.99_07';
+$VERSION = '2.99_08';
 
 # Backwards compatibility for exportable variable names.
 *verbose  = *Verbose;
@@ -78,15 +78,16 @@ $Timer = $ENV{HARNESS_TIMER} || 0;
 
 =head1 DESCRIPTION
 
-Although the L<Test::Harness> distribution takes its name from this
-module for historical reasons it exists only to provide L<TAP::Harness>
-with an interface that is somewhat backwards compatible with
-L<Test::Harness> 2.xx. If you're writing new code consider using
+Although, for historical reasons, the L<Test::Harness> distribution
+takes its name from this module it now exists only to provide
+L<TAP::Harness> with an interface that is somewhat backwards compatible
+with L<Test::Harness> 2.xx. If you're writing new code consider using
 L<TAP::Harness> directly instead.
 
 Emulation is provided for C<runtests> and C<execute_tests> but the
 pluggable 'Straps' interface that previous versions of L<Test::Harness>
-supported is not reproduced here.
+supported is not reproduced here. Straps is now available as a stand
+alone module: L<Test::Harness::Straps>.
 
 See L<TAP::Parser> for the main documentation for this distribution.
 
